// Stewart-MacDonald ukulele bridge

// Designed for the 8-Bit Ukulele
// http://www.8bitukulele.com
// by Theron Trowbridge
// Creative Commons Attribution 4.0 International (CC BY 4.0)
// https://creativecommons.org/licenses/by/4.0/

// parts:
// bridge
// 	width (X)
// 	depth (Y)
// 	height (Z)
// wings - optional
// 	width (X)
// 	(depth = bridge_depth) (Y)
// 	thickness (Z)
// saddle slot
// 	(width = bridge_width + fudge factor) (X)
// 	size (Y)
// 	depth (percentage of height of bridge minus height of wings) (Z)
// 	position (Y offset)
// string guide
// 	(width = bridge_width + fudge factor) (X)
// 	size (Y)
// 	depth (percentage of height of bridge minus height of wings) (Z)
// 	slope (percentage)
// hole block
// 	actually, just the remainder of the bridge block

fudge_factor = 0.1;

bridge_width = 40;
bridge_depth = 21.23;
bridge_height = 8.76;

wing_width = 82.55;
wing_height = 2.67;

saddle_slot_size = 2.99;
saddle_slot_depth_percentage = 0.9;
saddle_slot_depth = ((bridge_height-wing_height)*saddle_slot_depth_percentage)+fudge_factor;
saddle_slot_position = 4.25;

string_guide_size = 8;		// guess
string_guide_slope = 45;
temp_h = sqrt( 2 * ( string_guide_size * string_guide_size ) );


difference() {
	// bridge
	union() {
		translate( v=[0,0,(bridge_height/2)] ) {
			cube( size=[bridge_width,bridge_depth,bridge_height], center=true );
		}
		translate( v=[0,0,(wing_height/2)] ) {
			cube( size=[wing_width,bridge_depth,wing_height], center=true );
		}
	}

	// saddle slot
	translate( v=[0,(saddle_slot_size/2)-(bridge_depth/2)+saddle_slot_position,(saddle_slot_depth/2)+wing_height+(((bridge_height-wing_height)*(1-saddle_slot_depth_percentage)))] ) {
		cube( size=[(bridge_width+fudge_factor),saddle_slot_size,saddle_slot_depth], center=true );
	}

	// string guide
	difference() {
		translate( v=[0,(temp_h/2)-(bridge_depth/2)+(saddle_slot_position+saddle_slot_size),bridge_height] ) {
			rotate( a=string_guide_slope, v=[1,0,0] ) {
				cube(size=[(bridge_width+fudge_factor),string_guide_size,string_guide_size], center=true);
			}
		}
		translate( v=[0,(temp_h/2)-(bridge_depth/2)+(saddle_slot_position+saddle_slot_size)+(temp_h/2),bridge_height] ) {
			cube(size=[(bridge_width+fudge_factor),temp_h,temp_h],center=true );
		}
	}

}
