//	Ukulele Nut
//
//	version 1.2
//	created: 2012-08-17
//	modified: 2018-05-24
//
//	Nut for 8-Bit Ukulele
//  based on the Stwart Macdonald soprano ukulele
//
//	by Theron Trowbridge
//	http://www.8bitukulele.com
//
//  Creative Commons Attribution 4.0 International (CC BY 4.0)
//	https://creativecommons.org/licenses/by/4.0/
//	
//	Version History
//
//	version 0.9
//		based on measurements in Stewart Macdonald web site
//	Version 0.91
//		based on measurements of Stuart Macdonald nut
//	Version 0.92
//		minor formatting and modifications
//	Version 1.0
//		adjusting for the 8-bit ukulele
//	Version 1.1
//		adding a little extra height just in case
//  Version 1.2
//      updating license to CC BY 4.0
//

inch = 25.4;

nut_width = 1.5*inch;
nut_height = (5/16)*inch;
nut_thickness = (1/8)*inch;

blank_height=nut_height;

profile_radius = 5;
//profile_radius = 4;
top_radius = 304.8*2;

string_spacing = (3/8)*inch;
groove_depth = 0.8;
//groove_depth = 0.75;

$fa=0.01;

difference() {
	//	round over the profile
	intersection() {
		//	Z+, Y-
		translate( v=[0,-(blank_height/2),(nut_thickness/2)] ) {
			//	blank
			cube( size=[nut_width,blank_height,nut_thickness], center=true );
		}
		//	Y-
		translate( v=[0,-(profile_radius),0] ) {
			rotate( a=[0,90,0] ) {
				//	profile radius
				cylinder( r=profile_radius, h=(nut_width*2), center=true );
			}
		}
	}
	
	translate( v=[-((string_spacing/2)+string_spacing),(groove_depth/2),0] ) {
		rotate( a=[0,0,45] ) {
			cube( size=[groove_depth*2,groove_depth*2,nut_thickness*4], center=true );
		}
	}
	translate( v=[-(string_spacing/2),(groove_depth/2),0] ) {
		rotate( a=[0,0,45] ) {
			cube( size=[groove_depth*2,groove_depth*2,nut_thickness*4], center=true );
		}
	}
	translate( v=[(string_spacing/2),(groove_depth/2),0] ) {
		rotate( a=[0,0,45] ) {
			cube( size=[groove_depth*2,groove_depth*2,nut_thickness*4], center=true );
		}
	}
	translate( v=[(string_spacing/2)+string_spacing,(groove_depth/2),0] ) {
		rotate( a=[0,0,45] ) {
			cube( size=[groove_depth*2,groove_depth*2,nut_thickness*4], center=true );
		}
	}
}

